@@ -18,7 +18,7 @@ EC2_API = "http://%s/latest" % (EC2_HOST,)
 
 class InvalidCredentialsError(Exception):
     """
-    Raised when an invalid account title and/or registration password
+    Raised when an invalid account title and/or registration key
     is used with L{RegistrationManager.register}.
     """
 
@@ -62,7 +62,7 @@ class Identity(object):
     insecure_id = persist_property("insecure-id")
     computer_title = config_property("computer_title")
     account_name = config_property("account_name")
-    registration_password = config_property("registration_password")
+    registration_key = config_property("registration_key")
     tags = config_property("tags")
 
     def __init__(self, config, persist):
@@ -275,7 +275,7 @@ class RegistrationHandler(object):
                                "hostname": get_fqdn(),
                                "account_name": id.account_name,
                                "registration_password": \
-                                   id.registration_password,
+                                   id.registration_key,
                                "tags": tags,
                                "vm-info": get_vm_info()}
                     message.update(self._ec2_data)
@@ -283,7 +283,7 @@ class RegistrationHandler(object):
                 else:
                     self._reactor.fire("registration-failed")
             elif id.account_name:
-                with_word = ["without", "with"][bool(id.registration_password)]
+                with_word = ["without", "with"][bool(id.registration_key)]
                 with_tags = ["", u"and tags %s " % tags][bool(tags)]
                 logging.info(u"Queueing message to register with account %r %s"
                              "%s a password." % (id.account_name, with_tags,
@@ -291,7 +291,7 @@ class RegistrationHandler(object):
                 message = {"type": "register",
                            "computer_title": id.computer_title,
                            "account_name": id.account_name,
-                           "registration_password": id.registration_password,
+                           "registration_password": id.registration_key,
                            "hostname": get_fqdn(),
                            "tags": tags,
                            "vm-info": get_vm_info()}
