@@ -5,7 +5,7 @@ from landscape.lib.fetch import fetch_async
 from landscape.service import LandscapeService, run_landscape_service
 from landscape.broker.registration import RegistrationHandler, Identity
 from landscape.broker.config import BrokerConfiguration
-from landscape.broker.transport import HTTPTransport, PayloadRecorder
+from landscape.broker.transport import HTTPTransport
 from landscape.broker.exchange import MessageExchange
 from landscape.broker.exchangestore import ExchangeStore
 from landscape.broker.ping import Pinger
@@ -35,6 +35,8 @@ class BrokerService(LandscapeService):
     @ivar pinger: The L{Pinger} checks if the server has new messages for us.
     @ivar registration: The L{RegistrationHandler} performs the initial
         registration.
+
+    @param config: A L{BrokerConfiguration}.
     """
 
     transport_factory = HTTPTransport
@@ -42,19 +44,12 @@ class BrokerService(LandscapeService):
     service_name = BrokerServer.name
 
     def __init__(self, config):
-        """
-        @param config: A L{BrokerConfiguration}.
-        """
         self.persist_filename = os.path.join(
             config.data_path, "%s.bpickle" % (self.service_name,))
         super(BrokerService, self).__init__(config)
 
-        if config.record is not None:
-            self.payload_recorder = PayloadRecorder(config.record_directory)
-        else:
-            self.payload_recorder = None
         self.transport = self.transport_factory(
-            config.url, config.ssl_public_key, self.payload_recorder)
+            self.reactor, config.url, config.ssl_public_key)
         self.message_store = get_default_message_store(
             self.persist, config.message_store_path)
         self.identity = Identity(self.config, self.persist)
@@ -62,8 +57,8 @@ class BrokerService(LandscapeService):
         self.exchanger = MessageExchange(
             self.reactor, self.message_store, self.transport, self.identity,
             exchange_store, config)
-        self.pinger = self.pinger_factory(self.reactor, config.ping_url,
-                                          self.identity, self.exchanger)
+        self.pinger = self.pinger_factory(
+            self.reactor, self.identity, self.exchanger, config)
         self.registration = RegistrationHandler(
             config, self.identity, self.reactor, self.exchanger, self.pinger,
             self.message_store, fetch_async)
