@@ -1,5 +1,4 @@
 """Low-level server communication."""
-import os
 import time
 import logging
 import pprint
@@ -7,25 +6,22 @@ import pprint
 import pycurl
 
 from landscape.lib.fetch import fetch
-from landscape.lib.fs import create_file
 from landscape.lib import bpickle
 from landscape.log import format_delta
 from landscape import SERVER_API, VERSION
 
 
 class HTTPTransport(object):
-    """Transport makes a request to exchange message data over HTTP."""
+    """Transport makes a request to exchange message data over HTTP.
 
-    def __init__(self, url, pubkey=None, payload_recorder=None):
-        """
-        @param url: URL of the remote Landscape server message system.
-        @param pubkey: SSH public key used for secure communication.
-        @param payload_recorder: PayloadRecorder used for recording exchanges
-            with the server.  If C{None}, exchanges will not be recorded.
-        """
+    @param url: URL of the remote Landscape server message system.
+    @param pubkey: SSH public key used for secure communication.
+    """
+
+    def __init__(self, reactor, url, pubkey=None):
+        self._reactor = reactor
         self._url = url
         self._pubkey = pubkey
-        self._payload_recorder = payload_recorder
 
     def get_url(self):
         """Get the URL of the remote message system."""
@@ -60,13 +56,10 @@ class HTTPTransport(object):
 
         """
         spayload = bpickle.dumps(payload)
-        if self._payload_recorder is not None:
-            self._payload_recorder.save(spayload)
         try:
             start_time = time.time()
             if logging.getLogger().getEffectiveLevel() <= logging.DEBUG:
                 logging.debug("Sending payload:\n%s", pprint.pformat(payload))
-
             curly, data = self._curl(spayload, computer_id, message_api)
             logging.info("Sent %d bytes and received %d bytes in %s.",
                          len(spayload), len(data),
@@ -92,70 +85,11 @@ class HTTPTransport(object):
         return response
 
 
-class PayloadRecorder(object):
-    """
-    L{PayloadRecorder} records client exchanges with the server to disk for
-    later playback.
-
-    Exchange payloads will be stored one per file, where the file name is
-    the elapsed time since the client was started.
-    """
-
-    def __init__(self, destination_dir):
-        """
-        @param destination_dir - The directory to record exchanges in.
-        """
-        self._time_offset = time.time()
-        self._destination_dir = destination_dir
-        self._last_payload_time = -1
-        if self._destination_dir is not None:
-            self._create_destination_dir(self._destination_dir)
-            self._delete_old_payloads()
-
-    def _create_destination_dir(self, destination_dir):
-        """Create the destination directory if it does not exist.
-
-        @param destination_dir: The directory to be created.
-        """
-        if not os.path.exists(destination_dir):
-            os.mkdir(destination_dir)
-
-    def _delete_old_payloads(self):
-        """Delete payloads lying around from a previous session."""
-        for filename in os.listdir(self._destination_dir):
-            file_path = os.path.join(self._destination_dir, filename)
-            if os.path.isfile(file_path):
-                os.unlink(file_path)
-
-    def save(self, payload):
-        """Persist the given payload to disk.
-
-        @param payload: The payload to be persisted.
-        """
-        payload_name = self.get_payload_filename()
-        create_file(os.path.join(self._destination_dir, payload_name),
-                    payload)
-
-    def get_payload_filename(self):
-        """
-        Generate a payload filename.  This method ensures that payloads
-        will have a unique name.
-        """
-        payload_time = time.time() - self._time_offset
-        last_payload_time = '%.3f' % self._last_payload_time
-        this_payload_time = '%.3f' % payload_time
-        if last_payload_time == this_payload_time:
-            payload_time = payload_time + 0.001
-        self._last_payload_time = payload_time
-        return '%.3f' % payload_time
-
-
 class FakeTransport(object):
     """Fake transport for testing purposes."""
 
-    def __init__(self, url=None, pubkey=None, payload_recorder=None):
+    def __init__(self, reactor=None, url=None, pubkey=None):
         self._pubkey = pubkey
-        self._payload_recorder = payload_recorder
         self.payloads = []
         self.responses = []
         self._current_response = 0
@@ -164,6 +98,7 @@ class FakeTransport(object):
         self.message_api = None
         self.extra = {}
         self._url = url
+        self._reactor = reactor
 
     def get_url(self):
         return self._url
