@@ -130,7 +130,8 @@ def get_flags(sock, interface):
     return struct.unpack("H", data[16:18])[0]
 
 
-def get_active_device_info(skipped_interfaces=("lo",)):
+def get_active_device_info(skipped_interfaces=("lo",),
+                           skip_vlan=True, skip_alias=True):
     """
     Returns a dictionary containing information on each active network
     interface present on a machine.
@@ -140,6 +141,10 @@ def get_active_device_info(skipped_interfaces=("lo",)):
     for interface in get_active_interfaces(sock):
         if interface in skipped_interfaces:
             continue
+        if skip_vlan and "." in interface:
+            continue
+        if skip_alias and ":" in interface:
+            continue
         interface_info = {"interface": interface}
         interface_info["ip_address"] = get_ip_address(sock, interface)
         interface_info["mac_address"] = get_mac_address(sock, interface)
@@ -192,6 +197,9 @@ def get_fqdn():
         fqdn = socket.getaddrinfo(socket.gethostname(), None, socket.AF_INET,
                                   socket.SOCK_DGRAM, socket.IPPROTO_IP,
                                   socket.AI_CANONNAME)[0][3]
+        if "localhost" in fqdn:
+            # Another fallback
+            fqdn = socket.gethostname()
     return fqdn
 
 
