@@ -99,6 +99,10 @@ HARDWARE_INVENTORY = Message("hardware-inventory", {
                     )})
 
 
+HARDWARE_INFO = Message("hardware-info", {
+    "data": utf8})
+
+
 LOAD_AVERAGE = Message("load-average", {
     "load-averages": List(Tuple(Int(), Float())),
     })
@@ -134,6 +138,9 @@ FREE_SPACE = Message("free-space", {
 
 REGISTER = Message(
     "register",
+    # The term used in the UI is actually 'registration_key', but we keep
+    # the message schema field as 'registration_password' in case a new
+    # client contacts an older server.
     {"registration_password": Any(utf8, Constant(None)),
      "computer_title": utf8,
      "hostname": utf8,
@@ -143,6 +150,12 @@ REGISTER = Message(
     # hostname wasn't around in old versions
     optional=["registration_password", "hostname", "tags", "vm-info"])
 
+
+REGISTER_PROVISIONED_MACHINE = Message(
+    "register-provisioned-machine",
+    {"otp": String()})
+
+
 REGISTER_CLOUD_VM = Message(
     "register-cloud-vm",
     {"hostname": utf8,
@@ -153,13 +166,15 @@ REGISTER_CLOUD_VM = Message(
      "reservation_key": Unicode(),
      "public_hostname": Unicode(),
      "local_hostname": Unicode(),
-     "kernel_key": Unicode(),
+     "kernel_key": Any(Unicode(), Constant(None)),
      "ramdisk_key": Any(Unicode(), Constant(None)),
      "launch_index": Int(),
      "image_key": Unicode(),
      "tags": Any(utf8, Constant(None)),
-     "vm-info": String()},
-     optional=["tags", "vm-info"])
+     "vm-info": String(),
+     "public_ipv4": Unicode(),
+     "local_ipv4": Unicode()},
+     optional=["tags", "vm-info", "public_ipv4", "local_ipv4"])
 
 TEMPERATURE = Message("temperature", {
     "thermal-zone": utf8,
@@ -284,6 +299,12 @@ PACKAGE_LOCKS = Message(
      "deleted": package_locks},
     optional=["created", "deleted"])
 
+CHANGE_PACKAGE_HOLDS = Message(
+    "change-package-holds",
+    {"created": List(utf8),
+     "deleted": List(utf8)},
+    optional=["created", "deleted"])
+
 CHANGE_PACKAGES_RESULT = Message(
     "change-packages-result",
     {"operation-id": Int(),
@@ -386,10 +407,10 @@ NETWORK_ACTIVITY = Message(
 message_schemas = {}
 for schema in [ACTIVE_PROCESS_INFO, COMPUTER_UPTIME, CLIENT_UPTIME,
                OPERATION_RESULT, COMPUTER_INFO, DISTRIBUTION_INFO,
-               HARDWARE_INVENTORY, LOAD_AVERAGE, MEMORY_INFO,
+               HARDWARE_INVENTORY, HARDWARE_INFO, LOAD_AVERAGE, MEMORY_INFO,
                RESYNCHRONIZE, MOUNT_ACTIVITY, MOUNT_INFO, FREE_SPACE,
-               REGISTER, REGISTER_CLOUD_VM, TEMPERATURE, PROCESSOR_INFO,
-               USERS, PACKAGES, PACKAGE_LOCKS,
+               REGISTER, REGISTER_CLOUD_VM, REGISTER_PROVISIONED_MACHINE,
+               TEMPERATURE, PROCESSOR_INFO, USERS, PACKAGES, PACKAGE_LOCKS,
                CHANGE_PACKAGES_RESULT, UNKNOWN_PACKAGE_HASHES,
                ADD_PACKAGES, PACKAGE_REPORTER_RESULT, TEXT_MESSAGE, TEST,
                CUSTOM_GRAPH, REBOOT_REQUIRED, APT_PREFERENCES, EUCALYPTUS_INFO,
