@@ -10,10 +10,11 @@ from landscape.lib.sequenceranges import sequence_to_ranges
 from landscape.lib.twisted_util import gather_results, spawn_process
 from landscape.lib.fetch import fetch_async
 from landscape.lib.fs import touch_file
+from landscape.lib import bpickle
 
 from landscape.package.taskhandler import (
     PackageTaskHandlerConfiguration, PackageTaskHandler, run_task_handler)
-from landscape.package.store import UnknownHashIDRequest
+from landscape.package.store import UnknownHashIDRequest, FakePackageStore
 
 
 HASH_ID_REQUEST_TIMEOUT = 7200
@@ -29,9 +30,9 @@ class PackageReporterConfiguration(PackageTaskHandlerConfiguration):
         reporter-specific options.
         """
         parser = super(PackageReporterConfiguration, self).make_parser()
-        parser.add_option("--force-smart-update", default=False,
+        parser.add_option("--force-apt-update", default=False,
                           action="store_true",
-                          help="Force running smart-update.")
+                          help="Force running apt-update.")
         return parser
 
 
@@ -39,24 +40,22 @@ class PackageReporter(PackageTaskHandler):
     """Report information about the system packages.
 
     @cvar queue_name: Name of the task queue to pick tasks from.
-    @cvar smart_update_interval: Time interval in minutes to pass to
-        the C{--after} command line option of C{smart-update}.
+    @cvar apt_update_interval: Don't update the APT index more often
+        than the given interval in minutes.
     """
     config_factory = PackageReporterConfiguration
 
     queue_name = "reporter"
 
-    smart_update_interval = 60
-    smart_update_filename = "/usr/lib/landscape/smart-update"
+    apt_update_interval = 60
+    apt_update_filename = "/usr/lib/landscape/apt-update"
     sources_list_filename = "/etc/apt/sources.list"
     sources_list_directory = "/etc/apt/sources.list.d"
 
     def run(self):
         result = Deferred()
 
-        # Run smart-update before anything else, to make sure that
-        # the SmartFacade will load freshly updated channels
-        result.addCallback(lambda x: self.run_smart_update())
+        result.addCallback(lambda x: self.run_apt_update())
 
         # If the appropriate hash=>id db is not there, fetch it
         result.addCallback(lambda x: self.fetch_hash_id_db())
@@ -79,6 +78,9 @@ class PackageReporter(PackageTaskHandler):
         result.callback(None)
         return result
 
+    def send_message(self, message):
+        return self._broker.send_message(message, True)
+
     def fetch_hash_id_db(self):
         """
         Fetch the appropriate pre-canned database of hash=>id mappings
@@ -173,39 +175,53 @@ class PackageReporter(PackageTaskHandler):
 
         return False
 
-    def run_smart_update(self):
-        """Run smart-update and log a warning in case of non-zero exit code.
+    def _apt_update_timeout_expired(self, interval):
+        """Check if the apt-update timeout has passed."""
+        stamp = self._config.update_stamp_filename
+
+        if not os.path.exists(stamp):
+            return True
+        # check stamp file mtime
+        last_update = os.stat(stamp)[8]
+        now = int(time.time())
+        return (last_update + interval * 60) < now
+
+    def run_apt_update(self):
+        """Run apt-update and log a warning in case of non-zero exit code.
 
         @return: a deferred returning (out, err, code)
         """
-        if self._config.force_smart_update or self._apt_sources_have_changed():
-            args = ()
+        if (self._config.force_apt_update or self._apt_sources_have_changed()
+            or self._apt_update_timeout_expired(self.apt_update_interval)):
+
+            result = spawn_process(self.apt_update_filename)
+
+            def callback((out, err, code)):
+                touch_file(self._config.update_stamp_filename)
+                logging.debug(
+                    "'%s' exited with status %d (out='%s', err='%s')" % (
+                        self.apt_update_filename, code, out, err))
+
+                if code != 0:
+                    logging.warning("'%s' exited with status %d (%s)" % (
+                            self.apt_update_filename, code, err))
+                elif not self._facade.get_channels():
+                    code = 1
+                    err = ("There are no APT sources configured in %s or %s." %
+                           (self.sources_list_filename,
+                            self.sources_list_directory))
+
+                deferred = self._broker.call_if_accepted(
+                    "package-reporter-result", self.send_result, code, err)
+                deferred.addCallback(lambda ignore: (out, err, code))
+                return deferred
+
+            return result.addCallback(callback)
+
         else:
-            args = ("--after", str(self.smart_update_interval))
-        result = spawn_process(self.smart_update_filename, args=args)
-
-        def callback((out, err, code)):
-            # smart-update --after N will exit with error code 1 when it
-            # doesn't actually run the update code because to enough time
-            # has passed yet, but we don't actually consider it a failure.
-            smart_failed = False
-            if code != 0 and code != 1:
-                smart_failed = True
-            if code == 1 and err.strip() != "":
-                smart_failed = True
-            if smart_failed:
-                logging.warning("'%s' exited with status %d (%s)" % (
-                    self.smart_update_filename, code, err))
-            logging.debug("'%s' exited with status %d (out='%s', err='%s'" % (
-                self.smart_update_filename, code, out, err))
-            touch_file(self._config.smart_update_stamp_filename)
-            deferred = self._broker.call_if_accepted(
-                "package-reporter-result", self.send_result, code, err)
-            deferred.addCallback(lambda ignore: (out, err, code))
-            return deferred
-
-        result.addCallback(callback)
-        return result
+            logging.debug("'%s' didn't run, update interval has not passed" %
+                          self.apt_update_filename)
+            return succeed(("", "", 0))
 
     def send_result(self, code, err):
         """
@@ -215,7 +231,7 @@ class PackageReporter(PackageTaskHandler):
             "type": "package-reporter-result",
             "code": code,
             "err": err}
-        return self._broker.send_message(message, True)
+        return self.send_message(message)
 
     def handle_task(self, task):
         message = task.data
@@ -261,7 +277,6 @@ class PackageReporter(PackageTaskHandler):
         self._store.clear_available_upgrades()
         self._store.clear_installed()
         self._store.clear_locked()
-        self._store.clear_package_locks()
 
         # Don't clear the hash_id_requests table because the messages
         # associated with the existing requests might still have to be
@@ -343,7 +358,7 @@ class PackageReporter(PackageTaskHandler):
     def request_unknown_hashes(self):
         """Detect available packages for which we have no hash=>id mappings.
 
-        This method will verify if there are packages that Smart knows
+        This method will verify if there are packages that APT knows
         about but for which we don't have an id yet (no hash => id
         translation), and deliver a message (unknown-package-hashes)
         to request them.
@@ -385,7 +400,7 @@ class PackageReporter(PackageTaskHandler):
         """Create a hash_id_request and send message with "request-id"."""
         request = self._store.add_hash_id_request(unknown_hashes)
         message["request-id"] = request.id
-        result = self._broker.send_message(message, True)
+        result = self.send_message(message)
 
         def set_message_id(message_id):
             request.message_id = message_id
@@ -404,16 +419,13 @@ class PackageReporter(PackageTaskHandler):
         reactor.
         """
 
-        def changes_detected(results):
-            # Release all smart locks, in case the changer runs after us.
-            self._facade.deinit()
-            if True in results:
+        def changes_detected(result):
+            if result:
                 # Something has changed, notify the broker.
                 return self._broker.fire_event("package-data-changed")
 
-        result = gather_results([self.detect_packages_changes(),
-                                 self.detect_package_locks_changes()])
-        return result.addCallback(changes_detected)
+        deferred = self.detect_packages_changes()
+        return deferred.addCallback(changes_detected)
 
     def detect_packages_changes(self):
         """Detect changes in the universe of known packages.
@@ -454,30 +466,16 @@ class PackageReporter(PackageTaskHandler):
             hash = self._facade.get_package_hash(package)
             id = self._store.get_hash_id(hash)
             if id is not None:
-                if package.installed:
+                if self._facade.is_package_installed(package):
                     current_installed.add(id)
-                    for loader in package.loaders:
-                        # Is the package also in a non-installed
-                        # loader?  IOW, "available".
-                        if not loader.getInstalled():
-                            current_available.add(id)
-                            break
+                    if self._facade.is_package_available(package):
+                        current_available.add(id)
                 else:
                     current_available.add(id)
 
                 # Are there any packages that this package is an upgrade for?
-                for upgrade in package.upgrades:
-                    for provides in upgrade.providedby:
-                        for provides_package in provides.packages:
-                            if provides_package.installed:
-                                current_upgrades.add(id)
-                                break
-                        else:
-                            continue
-                        break
-                    else:
-                        continue
-                    break
+                if self._facade.is_package_upgrade(package):
+                    current_upgrades.add(id)
 
         for package in self._facade.get_locked_packages():
             hash = self._facade.get_package_hash(package)
@@ -526,7 +524,7 @@ class PackageReporter(PackageTaskHandler):
             return succeed(False)
 
         message["type"] = "packages"
-        result = self._broker.send_message(message, True)
+        result = self.send_message(message)
 
         logging.info("Queuing message with changes in known packages: "
                      "%d installed, %d available, %d available upgrades, "
@@ -561,56 +559,77 @@ class PackageReporter(PackageTaskHandler):
 
         return result
 
-    def detect_package_locks_changes(self):
-        """Detect changes in known package locks.
 
-        This method will verify if there are package locks that:
+class FakeGlobalReporter(PackageReporter):
+    """
+    A standard reporter, which additionally stores messages sent into its
+    package store.
+    """
 
-        - are now set, and were not;
-        - were previously set but are not anymore;
+    package_store_class = FakePackageStore
 
-        In all cases, the server is notified of the new situation
-        with a "packages" message.
+    def send_message(self, message):
+        self._store.save_message(message)
+        return super(FakeGlobalReporter, self).send_message(message)
 
-        @return: A deferred resulting in C{True} if package lock changes were
-            detected with respect to the previous run, or C{False} otherwise.
-        """
-        old_package_locks = set(self._store.get_package_locks())
-        current_package_locks = set(self._facade.get_package_locks())
 
-        set_package_locks = current_package_locks - old_package_locks
-        unset_package_locks = old_package_locks - current_package_locks
+class FakeReporter(PackageReporter):
+    """
+    A fake reporter which only sends messages previously stored by a
+    L{FakeGlobalReporter}.
+    """
 
-        message = {}
-        if set_package_locks:
-            message["created"] = sorted(set_package_locks)
-        if unset_package_locks:
-            message["deleted"] = sorted(unset_package_locks)
+    package_store_class = FakePackageStore
+    global_store_filename = None
 
-        if not message:
-            return succeed(False)
+    def run(self):
+        result = succeed(None)
 
-        message["type"] = "package-locks"
-        result = self._broker.send_message(message, True)
+        # If the appropriate hash=>id db is not there, fetch it
+        result.addCallback(lambda x: self.fetch_hash_id_db())
 
-        logging.info("Queuing message with changes in known package locks:"
-                     " %d created, %d deleted." %
-                     (len(set_package_locks), len(unset_package_locks)))
+        result.addCallback(lambda x: self._store.clear_tasks())
 
-        def update_currently_known(result):
-            if set_package_locks:
-                self._store.add_package_locks(set_package_locks)
-            if unset_package_locks:
-                self._store.remove_package_locks(unset_package_locks)
-            return True
-
-        result.addCallback(update_currently_known)
+        # Finally, verify if we have anything new to send to the server.
+        result.addCallback(lambda x: self.send_pending_messages())
 
         return result
 
+    def send_pending_messages(self):
+        """
+        As the last callback of L{PackageReporter}, sends messages stored.
+        """
+        if self.global_store_filename is None:
+            self.global_store_filename = os.environ["FAKE_PACKAGE_STORE"]
+        if not os.path.exists(self.global_store_filename):
+            return succeed(None)
+        message_sent = set(self._store.get_message_ids())
+        global_store = FakePackageStore(self.global_store_filename)
+        all_message_ids = set(global_store.get_message_ids())
+        not_sent = all_message_ids - message_sent
+        deferred = succeed(None)
+        got_type = set()
+        if not_sent:
+            messages = global_store.get_messages_by_ids(not_sent)
+            sent = []
+            for message_id, message in messages:
+                message = bpickle.loads(str(message))
+                if message["type"] not in got_type:
+                    got_type.add(message["type"])
+                    sent.append(message_id)
+                    deferred.addCallback(
+                        lambda x, message=message: self.send_message(message))
+            self._store.save_message_ids(sent)
+        return deferred
+
 
 def main(args):
-    return run_task_handler(PackageReporter, args)
+    if "FAKE_GLOBAL_PACKAGE_STORE" in os.environ:
+        return run_task_handler(FakeGlobalReporter, args)
+    elif "FAKE_PACKAGE_STORE" in os.environ:
+        return run_task_handler(FakeReporter, args)
+    else:
+        return run_task_handler(PackageReporter, args)
 
 
 def find_reporter_command():
