@@ -173,8 +173,8 @@ class LandscapeSetupScriptTest(LandscapeTest):
         self.mocker.result("password")
         self.mocker.replay()
 
-        self.script.password_prompt("registration_password", "Password")
-        self.assertEqual(self.config.registration_password, "password")
+        self.script.password_prompt("registration_key", "Password")
+        self.assertEqual(self.config.registration_key, "password")
 
     def test_password_prompt_simple_non_matching(self):
         mock = self.mocker.replace(getpass, passthrough=False)
@@ -182,7 +182,7 @@ class LandscapeSetupScriptTest(LandscapeTest):
         self.mocker.result("password")
 
         script_mock = self.mocker.patch(self.script)
-        script_mock.show_help("Passwords must match.")
+        script_mock.show_help("Keys must match.")
 
         mock("Please confirm: ")
         self.mocker.result("")
@@ -191,8 +191,8 @@ class LandscapeSetupScriptTest(LandscapeTest):
         mock("Please confirm: ")
         self.mocker.result("password")
         self.mocker.replay()
-        self.script.password_prompt("registration_password", "Password")
-        self.assertEqual(self.config.registration_password, "password")
+        self.script.password_prompt("registration_key", "Password")
+        self.assertEqual(self.config.registration_key, "password")
 
     def test_password_prompt_simple_matching_required(self):
         mock = self.mocker.replace(getpass, passthrough=False)
@@ -210,8 +210,8 @@ class LandscapeSetupScriptTest(LandscapeTest):
 
         self.mocker.replay()
 
-        self.script.password_prompt("registration_password", "Password", True)
-        self.assertEqual(self.config.registration_password, "password")
+        self.script.password_prompt("registration_key", "Password", True)
+        self.assertEqual(self.config.registration_key, "password")
 
     def test_prompt_yes_no(self):
         comparisons = [("Y", True),
@@ -291,24 +291,24 @@ class LandscapeSetupScriptTest(LandscapeTest):
         self.config.load_command_line(["-a", "Account name"])
         self.script.query_account_name()
 
-    def test_query_registration_password(self):
-        help_snippet = "A registration password may be"
+    def test_query_registration_key(self):
+        help_snippet = "A registration key may be"
         self.mocker.order()
         script_mock = self.mocker.patch(self.script)
         script_mock.show_help(self.get_matcher(help_snippet))
-        script_mock.password_prompt("registration_password",
-                                    "Account registration password")
+        script_mock.password_prompt("registration_key",
+                                    "Account registration key")
         self.mocker.replay()
-        self.script.query_registration_password()
+        self.script.query_registration_key()
 
-    def test_query_registration_password_defined_on_command_line(self):
+    def test_query_registration_key_defined_on_command_line(self):
         getpass_mock = self.mocker.replace("getpass.getpass",
                                            passthrough=False)
         self.expect(getpass_mock(ANY)).count(0)
         self.mocker.replay()
 
         self.config.load_command_line(["-p", "shared-secret"])
-        self.script.query_registration_password()
+        self.script.query_registration_key()
 
     def test_query_proxies(self):
         help_snippet = "The Landscape client communicates"
@@ -565,7 +565,7 @@ class LandscapeSetupScriptTest(LandscapeTest):
         self.mocker.order()
         script_mock = self.mocker.patch(self.script)
         script_mock.show_help("You may provide tags for this computer e.g. "
-                              "server,hardy.")
+                              "server,precise.")
         script_mock.prompt("tags", "Tags", False)
         self.mocker.replay()
         self.script.query_tags()
@@ -578,7 +578,7 @@ class LandscapeSetupScriptTest(LandscapeTest):
         """
         script_mock = self.mocker.patch(self.script)
         script_mock.show_help("You may provide tags for this computer e.g. "
-                              "server,hardy.")
+                              "server,precise.")
         script_mock.prompt_get_input("Tags: ", False)
         self.mocker.result(u"<script>alert();</script>")
         script_mock.show_help("Tag names may only contain alphanumeric "
@@ -619,7 +619,7 @@ class LandscapeSetupScriptTest(LandscapeTest):
         script_mock.show_header()
         script_mock.query_computer_title()
         script_mock.query_account_name()
-        script_mock.query_registration_password()
+        script_mock.query_registration_key()
         script_mock.query_proxies()
         script_mock.query_script_plugin()
         script_mock.query_tags()
@@ -656,7 +656,7 @@ class ConfigurationFunctionsTest(LandscapeTest):
         filename = self.makeFile("[client]\n"
                                  "computer_title = Old Title\n"
                                  "account_name = Old Name\n"
-                                 "registration_password = Old Password\n"
+                                 "registration_key = Old Password\n"
                                  "http_proxy = http://old.proxy\n"
                                  "https_proxy = https://old.proxy\n"
                                  "url = http://url\n"
@@ -671,7 +671,7 @@ class ConfigurationFunctionsTest(LandscapeTest):
 
         expect(raw_input(C("[Old Title]"))).result("New Title")
         expect(raw_input(C("[Old Name]"))).result("New Name")
-        expect(getpass(C("registration password:"))).result("New Password")
+        expect(getpass(C("Account registration key:"))).result("New Password")
         expect(getpass(C("Please confirm:"))).result("New Password")
         expect(raw_input(C("[http://old.proxy]"))).result("http://new.proxy")
         expect(raw_input(C("[https://old.proxy]"))).result("https://new.proxy")
@@ -696,7 +696,7 @@ class ConfigurationFunctionsTest(LandscapeTest):
 
         self.assertEqual(config.computer_title, "New Title")
         self.assertEqual(config.account_name, "New Name")
-        self.assertEqual(config.registration_password, "New Password")
+        self.assertEqual(config.registration_key, "New Password")
         self.assertEqual(config.http_proxy, "http://new.proxy")
         self.assertEqual(config.https_proxy, "https://new.proxy")
         self.assertEqual(config.include_manager_plugins, "")
@@ -749,7 +749,7 @@ data_path = %s
         args = ["--silent", "--no-start",
                 "--computer-title", "",
                 "--account-name", "",
-                "--registration-password", "",
+                "--registration-key", "",
                 "--url", "https://landscape.canonical.com/message-system",
                 "--exchange-interval", "900",
                 "--urgent-exchange-interval", "60",
@@ -767,11 +767,10 @@ data_path = %s
             "http_proxy = \n"
             "tags = \n"
             "data_path = %s\n"
-            "registration_password = \n"
+            "registration_key = \n"
             "account_name = \n"
             "computer_title = \n"
             "https_proxy = \n"
-            "ping_url = http://landscape.canonical.com/ping\n"
              % config.data_path)
 
     def test_silent_setup_without_computer_title(self):
@@ -883,7 +882,7 @@ bus = session
         filename = self.makeFile("""
 [client]
 ping_url = http://landscape.canonical.com/ping
-registration_password = shared-secret
+registration_key = shared-secret
 log_level = debug
 random_key = random_value
 """)
@@ -895,7 +894,7 @@ random_key = random_value
         parser.read(filename)
         self.assertEqual(
             {"log_level": "debug",
-             "registration_password": "shared-secret",
+             "registration_key": "shared-secret",
              "ping_url": "http://localhost/ping",
              "random_key": "random_value",
              "computer_title": "rex",
@@ -937,7 +936,7 @@ random_key = random_value
 
         filename = self.makeFile("""
 [client]
-registration_password = shared-secret
+registration_key = shared-secret
 """)
         config = self.get_config(["--config", filename, "--silent",
                                   "-a", "account", "-t", "rex"])
@@ -945,7 +944,7 @@ registration_password = shared-secret
         parser = ConfigParser()
         parser.read(filename)
         self.assertEqual(
-            {"registration_password": "shared-secret",
+            {"registration_key": "shared-secret",
              "http_proxy": "http://environ",
              "https_proxy": "https://environ",
              "computer_title": "rex",
@@ -1011,7 +1010,7 @@ registration_password = shared-secret
             "[client]\n"
             "computer_title = Old Title\n"
             "account_name = Old Name\n"
-            "registration_password = Old Password\n"
+            "registration_key = Old Password\n"
             )
         main(["-c", config_filename, "--silent"])
 
@@ -1019,7 +1018,7 @@ registration_password = shared-secret
         return self.makeFile("[client]\n"
                              "computer_title = Old Title\n"
                              "account_name = Old Name\n"
-                             "registration_password = Old Password\n"
+                             "registration_key = Old Password\n"
                              "http_proxy = http://old.proxy\n"
                              "https_proxy = https://old.proxy\n"
                              "url = http://url\n")
@@ -1215,7 +1214,7 @@ registration_password = shared-secret
             "[client]\n"
             "computer_title = New Title\n"
             "account_name = New Name\n"
-            "registration_password = New Password\n"
+            "registration_key = New Password\n"
             "http_proxy = http://new.proxy\n"
             "https_proxy = https://new.proxy\n"
             "url = http://new.url\n")
@@ -1234,7 +1233,7 @@ registration_password = shared-secret
         self.assertEqual(dict(options.items("client")),
                          {"computer_title": "New Title",
                           "account_name": "New Name",
-                          "registration_password": "New Password",
+                          "registration_key": "New Password",
                           "http_proxy": "http://new.proxy",
                           "https_proxy": "https://new.proxy",
                           "url": "http://new.url"})
@@ -1317,7 +1316,7 @@ registration_password = shared-secret
             "[client]\n"
             "computer_title = Old Title\n"
             "account_name = Old Name\n"
-            "registration_password = Old Password\n"
+            "registration_key = Old Password\n"
             "http_proxy = http://old.proxy\n"
             "https_proxy = https://old.proxy\n"
             "url = http://old.url\n")
@@ -1325,7 +1324,7 @@ registration_password = shared-secret
         new_configuration = (
             "[client]\n"
             "account_name = New Name\n"
-            "registration_password = New Password\n"
+            "registration_key = New Password\n"
             "url = http://new.url\n")
 
         config_filename = self.makeFile(old_configuration,
@@ -1345,7 +1344,7 @@ registration_password = shared-secret
         self.assertEqual(dict(options.items("client")),
                          {"computer_title": "Old Title",
                           "account_name": "New Name",
-                          "registration_password": "Command Line Password",
+                          "registration_key": "Command Line Password",
                           "http_proxy": "http://old.proxy",
                           "https_proxy": "https://old.proxy",
                           "url": "http://new.url"})
@@ -1366,12 +1365,12 @@ registration_password = shared-secret
             "[client]\n"
             "computer_title = Old Title\n"
             "account_name = Old Name\n"
-            "registration_password = Old Password\n"
+            "registration_key = Old Password\n"
             "url = http://old.url\n")
 
         new_configuration = (
             "[client]\n"
-            "registration_password =\n")
+            "registration_key =\n")
 
         config_filename = self.makeFile(old_configuration,
                                         basename="final_config")
@@ -1388,7 +1387,7 @@ registration_password = shared-secret
         self.assertEqual(dict(options.items("client")),
                          {"computer_title": "Old Title",
                           "account_name": "Old Name",
-                          "registration_password": "",  # <==
+                          "registration_key": "",  # <==
                           "url": "http://old.url"})
 
     def test_import_from_url(self):
@@ -1401,7 +1400,7 @@ registration_password = shared-secret
             "[client]\n"
             "computer_title = New Title\n"
             "account_name = New Name\n"
-            "registration_password = New Password\n"
+            "registration_key = New Password\n"
             "http_proxy = http://new.proxy\n"
             "https_proxy = https://new.proxy\n"
             "url = http://new.url\n")
@@ -1427,7 +1426,7 @@ registration_password = shared-secret
         self.assertEqual(dict(options.items("client")),
                          {"computer_title": "New Title",
                           "account_name": "New Name",
-                          "registration_password": "New Password",
+                          "registration_key": "New Password",
                           "http_proxy": "http://new.proxy",
                           "https_proxy": "https://new.proxy",
                           "url": "http://new.url"})
@@ -1711,7 +1710,7 @@ class RegisterFunctionTest(LandscapeTest):
         self.mocker.call(register_done)
 
         # The deferred errback finally prints out this message.
-        print_text_mock("Invalid account name or registration password.",
+        print_text_mock("Invalid account name or registration key.",
                         error=True)
 
         reactor_mock.stop()
